@@ -4,11 +4,13 @@ set -e
 if [ "$1" != "" ]
 then
     PY_VER=$1
+    shift
 fi
 
-if [ "$2" != "" ]
+if [ "$1" != "" ]
 then
-    SVN_VER=$2
+    shift
+    SVN_VER=$1
 fi
 
 export MACOSX_DEPLOYMENT_TARGET=10.9
@@ -17,7 +19,8 @@ case "$(uname)" in
 Linux)
     python${PY_VER} setup.py configure \
         --enable-debug \
-        --verbose
+        --verbose \
+        "$@"
     ;;
 
 Darwin)
@@ -26,7 +29,9 @@ Darwin)
         --distro-dir=/Applications/Xcode.app/Contents/Developer/Platforms/MacOSX.platform/Developer/SDKs/MacOSX10.11.sdk/usr \
         --arch=x86_64 \
         --pycxx-dir=${BUILDER_TOP_DIR}/Import/pycxx-${PYCXX_VER} \
-        --verbose
+        --define=APR_IOVEC_DEFINED \
+        --verbose \
+        "$@"
     ;;
 *)
     echo "Error: need support for $(uname)"
